/*
 
 This file is part of Subconnector.
 
 Subconnector is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 Subconnector is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Subconnector. If not, see <http://www.gnu.org/licenses/>.
 
 Copyright 2012, 2013 Alejandro Celaya Alastrué
 
 */

package net.subclient.subsonic.util;

/**
 * Handles HTML entities decoding
 * @author Alejandro Celaya Alastrué
 */
public class HTMLUtils {
	
	/**
	 * Decodes all HTML entities in the input string nad returns it.
	 * It seems that Subsonic replaces all special characters by html entities. This solves that problem.
	 * @param input String before decoding HTML entities
	 * @return Decoded string
	 */
	public static String decode(String input) {
		return input
				//ISO 8859-1 Symbols
				.replaceAll("&#161;", "¡")
				.replaceAll("&#162;", "¢")
				.replaceAll("&#163;", "£")
				.replaceAll("&#164;", "¤")
				.replaceAll("&#165;", "¥")
				.replaceAll("&#166;", "¦")
				.replaceAll("&#167;", "§")
				.replaceAll("&#168;", "¨")
				.replaceAll("&#169;", "©")
				.replaceAll("&#170;", "ª")
				.replaceAll("&#171;", "«")
				.replaceAll("&#172;", "¬")
				.replaceAll("&#174;", "®")
				.replaceAll("&#175;", "¯")
				.replaceAll("&#176;", "°")
				.replaceAll("&#177;", "±")
				.replaceAll("&#178;", "²")
				.replaceAll("&#179;", "³")
				.replaceAll("&#180;", "´")
				.replaceAll("&#181;", "µ")
				.replaceAll("&#182;", "¶")
				.replaceAll("&#183;", "·")
				.replaceAll("&#184;", "¸")
				.replaceAll("&#185;", "¹")
				.replaceAll("&#186;", "º")
				.replaceAll("&#187;", "»")
				.replaceAll("&#188;", "¼")
				.replaceAll("&#189;", "½")
				.replaceAll("&#190;", "¾")
				.replaceAll("&#191;", "¿")
				.replaceAll("&#215;", "×")
				.replaceAll("&#247;", "÷")
				//ISO 8859-1 Characters
				.replaceAll("&#192;", "À")
				.replaceAll("&#193;", "Á")
				.replaceAll("&#194;", "Â")
				.replaceAll("&#195;", "Ã")
				.replaceAll("&#196;", "Ä")
				.replaceAll("&#197;", "Å")
				.replaceAll("&#198;", "Æ")
				.replaceAll("&#199;", "Ç")
				.replaceAll("&#200;", "È")
				.replaceAll("&#201;", "É")
				.replaceAll("&#202;", "Ê")
				.replaceAll("&#203;", "Ë")
				.replaceAll("&#204;", "Ì")
				.replaceAll("&#205;", "Í")
				.replaceAll("&#206;", "Î")
				.replaceAll("&#207;", "Ï")
				.replaceAll("&#208;", "Ð")
				.replaceAll("&#209;", "Ñ")
				.replaceAll("&#210;", "Ò")
				.replaceAll("&#211;", "Ó")
				.replaceAll("&#212;", "Ô")
				.replaceAll("&#213;", "Õ")
				.replaceAll("&#214;", "Ö")
				.replaceAll("&#216;", "Ø")
				.replaceAll("&#217;", "Ù")
				.replaceAll("&#218;", "Ú")
				.replaceAll("&#219;", "Û")
				.replaceAll("&#220;", "Ü")
				.replaceAll("&#221;", "Ý")
				.replaceAll("&#222;", "Þ")
				.replaceAll("&#223;", "ß")
				.replaceAll("&#224;", "à")
				.replaceAll("&#225;", "á")
				.replaceAll("&#226;", "â")
				.replaceAll("&#227;", "ã")
				.replaceAll("&#228;", "ä")
				.replaceAll("&#229;", "å")
				.replaceAll("&#230;", "æ")
				.replaceAll("&#231;", "ç")
				.replaceAll("&#232;", "è")
				.replaceAll("&#233;", "é")
				.replaceAll("&#234;", "ê")
				.replaceAll("&#235;", "ë")
				.replaceAll("&#236;", "ì")
				.replaceAll("&#237;", "í")
				.replaceAll("&#238;", "î")
				.replaceAll("&#239;", "ï")
				.replaceAll("&#240;", "ð")
				.replaceAll("&#241;", "ñ")
				.replaceAll("&#242;", "ò")
				.replaceAll("&#243;", "ó")
				.replaceAll("&#244;", "ô")
				.replaceAll("&#245;", "õ")
				.replaceAll("&#246;", "ö")
				.replaceAll("&#248;", "ø")
				.replaceAll("&#249;", "ù")
				.replaceAll("&#250;", "ú")
				.replaceAll("&#251;", "û")
				.replaceAll("&#252;", "ü")
				.replaceAll("&#253;", "ý")
				.replaceAll("&#254;", "þ")
				.replaceAll("&#255;", "ÿ")
				//Other entities
				.replaceAll("&#338;", "Œ")
				.replaceAll("&#339;", "œ")
				.replaceAll("&#352;", "Š")
				.replaceAll("&#353;", "š")
				.replaceAll("&#376;", "Ÿ")
				.replaceAll("&#402;", "ƒ")
				.replaceAll("&#710;", "ˆ")
				.replaceAll("&#732;", "˜")
				.replaceAll("&#8211;", "–")
				.replaceAll("&#8212;", "—")
				.replaceAll("&#8216;", "‘")
				.replaceAll("&#8217;", "’")
				.replaceAll("&#8218;", "‚")
				.replaceAll("&#8220;", "“")
				.replaceAll("&#8221;", "”")
				.replaceAll("&#8222;", "„")
				.replaceAll("&#8224;", "†")
				.replaceAll("&#8226;", "•")
				.replaceAll("&#8230;", "…")
				.replaceAll("&#8240;", "‰")
				.replaceAll("&#8249;", "‹")
				.replaceAll("&#8250;", "›")
				.replaceAll("&#8364;", "€")
				.replaceAll("&#8482;", "™")
				.replaceAll("&#153;", "™");
	}
	
}
